@@ -24,7 +24,7 @@ use Search::Query::Dialect::Lucy;
 
 use namespace::sweep;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 has 'find_relevant_fields' => ( is => 'rw', isa => Bool, default => sub {0} );
 has 'nfs_mode'             => ( is => 'rw', isa => Bool, default => sub {0} );
@@ -178,7 +178,7 @@ sub _build_lucy {
     else {
         $self->{qp} = $self->{_initial_qp};
     }
-    
+
     $self->debug and warn dump $self;
 
     return $self;
@@ -376,9 +376,12 @@ sub search {
         dump( $hits_args{query}->dump() ),
         dump( \%hits_args )
         );
-    my $compiler = $hits_args{query}->make_compiler( searcher => $lucy );
-    my $hits     = $lucy->hits(%hits_args);
-    my $results  = Dezi::Lucy::Results->new(
+    my $compiler = $hits_args{query}->make_compiler(
+        searcher => $lucy,
+        boost    => 0,
+    );
+    my $hits    = $lucy->hits(%hits_args);
+    my $results = Dezi::Lucy::Results->new(
         hits                 => $hits->total_hits + 0,
         payload              => $hits,
         query                => $parsed_query,
